![banner](https://raw.githubusercontent.com/Enchan1207/blueprintpy/master/banner.png)

[![pypi](https://img.shields.io/pypi/v/blueprintpy)](https://pypi.org/project/blueprintpy/)

## Overview

Generic package configurating utility

## Description

**blueprintpy** is a generic utility that provides package configurating CLI like `npm init` or `swift init`.

By default it contains generic Python package configuration (pypi-compliant), but you can customize it.  
Furthermore, each configuration is managed as **Template**, so you can create your own template.

## Installation

blueprintpy can be installed from PyPI. The CLI tool `blueprint` will also be installed.

```
pip install blueprintpy
```


## Documents

Documents and API references are publised at [GitHub Pages](https://enchan1207.github.io/blueprintpy/index.html).  

## License

This repository is published under [MIT License](https://github.com/Enchan1207/blueprintpy/blob/master/LICENSE).
